@@ -1,5 +1,4 @@
 library(testthat)
-library(metalite)
 library(metalite.ae)
-library(r2rtf)
+
 test_check("metalite.ae")
